function g = projplot2(Y,T,curve)
%Does the same thing as "projplot(Y,1,curve)", only
%replacing the projection pole [1;0;0;0] by 
%T[1;0;0;0], where T should be an orthogonal 4x4 matrix

if nargin<3
    curve=0;
end
Ydims=size(Y); xpoints=Ydims(1)/5; ypoints=Ydims(2); 
Ys=zeros(xpoints*4,ypoints);


for row=1:xpoints
  for j=1:ypoints
      x1=Y(5*row-3,j)/Y(5*row-4,j);
      x2=Y(5*row-2,j)/Y(5*row-4,j);
      x3=Y(5*row-1,j)/Y(5*row-4,j);
      x4=Y(5*row,j)/Y(5*row-4,j);
      rotated=T*[x1;x2;x3;x4];
      Ys(row,j)=rotated(1);
      Ys(xpoints+row,j)=rotated(2);
      Ys(2*xpoints+row,j)=rotated(3);
      Ys(3*xpoints+row,j)=rotated(4);
  end
end  

X=zeros(xpoints,ypoints); Y=zeros(xpoints,ypoints); Z=zeros(xpoints,ypoints);
for ix=1:xpoints
    for iy=1:ypoints
        scalefactor=1-Ys(ix,iy);
        X(ix,iy)=Ys(xpoints+ix,iy)/scalefactor;
        Y(ix,iy)=Ys(xpoints*2+ix,iy)/scalefactor;
        Z(ix,iy)=Ys(xpoints*3+ix,iy)/scalefactor;
    end
end
g=[X;Y;Z]; 

surf(g(1:xpoints, :), g(xpoints+1: 2*xpoints, :),  g(2*xpoints+1: 3*xpoints, :),'Clipping','off','BackFaceLight','unlit','EdgeAlpha',0.3,'FaceAlpha',1,'LineWidth',1,'FaceLighting','gouraud','DiffuseStrength',0.7,'EdgeLighting','gouraud','EdgeColor','w','FaceColor',[0.7,0.75,0.9])
daspect([1 1 1])
hold all
if curve
plot3(g(1:xpoints, curve:curve), g(xpoints+1: 2*xpoints, curve:curve),  g(2*xpoints+1: 3*xpoints, curve:curve),'color',[0.7 0 0],'LineWidth',1.2)
end
hold off
end

